@@ -52,7 +52,7 @@ class ModelsEvaluator:
                 prob_related = math.exp(log_probs.data.tolist()[0][1])
 
                 print("type(label) : ", type(label))
-                if(label == "1"):
+                if ((type(label) == str) & (label == "1")) |  ((type(label) == int) & (label == 1)):
                     # true label is disaster related
                     related_confs.append(prob_related)
                     if prob_related > 0.5:
