@@ -345,7 +345,7 @@ class RunConfigurationProvider:
         # Set Docker base image to the default CPU-based image
         #DOCKER_ARGUMENTS = ["all"]
         #huml_env.docker.arguments = DOCKER_ARGUMENTS
-        huml_env.docker.base_image = "mcr.microsoft.com/azureml/onnxruntime:latest-cuda"
+        #huml_env.docker.base_image = "mcr.microsoft.com/azureml/onnxruntime:latest-cuda"
 
         # Add the dependencies to the environment
         huml_env.python.conda_dependencies = packages
